@@ -1,11 +1,12 @@
 from .bertscore import BertScore
-from .deltascore import DeltaScore
 from .efficientscore import EfficientScore
 from .icdscore import ICDScore
+from .medconscore import MedconScore
 
 __all__ = [
-    "BertScore",
-    "DeltaScore", 
+    "BertScore", 
     "EfficientScore",
-    "ICDScore"
+    "ICDScore",
+    "MedconScore"
 ]
+
